==> antd-mobile-1.0.1.tgz: package/lib/radio/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _list=require('antd-mobile/components/list');var _list2=_interopRequireDefault(_list);var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _radio=require('antd-mobile/components/radio');var _radio2=_interopRequireDefault(_radio);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}

var RadioItem=_radio2["default"].RadioItem;var
BasicRadioExample=function(_React$Component){(0,_inherits3["default"])(BasicRadioExample,_React$Component);
function BasicRadioExample(){(0,_classCallCheck3["default"])(this,BasicRadioExample);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.state={
part1Value:1,
part2Value:1};return _this;

}BasicRadioExample.prototype.
render=function render(){var _this2=this;
return _react2["default"].createElement(_reactNative.View,null,
_react2["default"].createElement(_reactNative.View,{style:{padding:10}},
_react2["default"].createElement(_radio2["default"],{checked:this.state.part1Value===1,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part1Value:1});
}
},style:{borderWidth:1,borderColor:'#999',margin:10}},'\u652F\u6301'),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_radio2["default"],{checked:this.state.part1Value===2,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part1Value:2});
}
},style:{borderWidth:1,borderColor:'#999',margin:10}}),
_react2["default"].createElement(_whiteSpace2["default"],null)),


_react2["default"].createElement(_list2["default"],{style:{marginTop:12}},
_react2["default"].createElement(_reactNative.Text,{style:{marginTop:12}},'\u8868\u5355\u5355\u9009\u9879\uFF0C\u666E\u901A\u5217\u8868\u4E2D\u5355\u9009\u9879'),
_react2["default"].createElement(RadioItem,{checked:this.state.part2Value===1,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part2Value:1});
}
}},'\u4F7F\u7528 Ant Desgin Component'),


_react2["default"].createElement(RadioItem,{checked:this.state.part2Value===2,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part2Value:2});
}
}},'\u4F7F\u7528 Ant Desgin Component'),


_react2["default"].createElement(RadioItem,{disabled:true},'\u4E2A\u6027\u5316\u8C03\u6574disabled'),
_react2["default"].createElement(RadioItem,{disabled:true,checked:true},'\u4E2A\u6027\u5316\u8C03\u6574disabled')));


};return BasicRadioExample;}(_react2["default"].Component);exports["default"]=BasicRadioExample;module.exports=exports['default'];

==> antd-mobile-1.1.1.tgz: package/lib/radio/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _list=require('antd-mobile/components/list');var _list2=_interopRequireDefault(_list);var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _radio=require('antd-mobile/components/radio');var _radio2=_interopRequireDefault(_radio);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}

var RadioItem=_radio2["default"].RadioItem;var
BasicRadioExample=function(_React$Component){(0,_inherits3["default"])(BasicRadioExample,_React$Component);
function BasicRadioExample(){(0,_classCallCheck3["default"])(this,BasicRadioExample);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.apply(this,arguments));
_this.state={
part1Value:1,
part2Value:1};return _this;

}BasicRadioExample.prototype.
render=function render(){var _this2=this;
return _react2["default"].createElement(_reactNative.View,null,
_react2["default"].createElement(_reactNative.View,{style:{padding:10}},
_react2["default"].createElement(_radio2["default"],{checked:this.state.part1Value===1,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part1Value:1});
}
},style:{borderWidth:1,borderColor:'#999',margin:10}},'Support'),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_radio2["default"],{checked:this.state.part1Value===2,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part1Value:2});
}
},style:{borderWidth:1,borderColor:'#999',margin:10}}),
_react2["default"].createElement(_whiteSpace2["default"],null)),


_react2["default"].createElement(_list2["default"],{style:{marginTop:12}},
_react2["default"].createElement(_reactNative.Text,{style:{marginTop:12}},'Form radio, radio in general list.'),
_react2["default"].createElement(RadioItem,{checked:this.state.part2Value===1,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part2Value:1});
}
}},'Use Ant Desgin Component'),


_react2["default"].createElement(RadioItem,{checked:this.state.part2Value===2,onChange:function onChange(event){
if(event.target.checked){
_this2.setState({part2Value:2});
}
}},'Use Ant Desgin Component'),


_react2["default"].createElement(RadioItem,{disabled:true},'Set disabled'),
_react2["default"].createElement(RadioItem,{disabled:true,checked:true},'Set disabled')));


};return BasicRadioExample;}(_react2["default"].Component);exports["default"]=BasicRadioExample;module.exports=exports['default'];
